==> httpclient-4.3.4-sources.jar: cz/msebera/android/httpclient/impl/auth/SpnegoTokenGenerator.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package cz.msebera.android.httpclient.impl.auth;

import java.io.IOException;

/**
 * Abstract SPNEGO token generator. Implementations should take an Kerberos ticket and transform
 * into a SPNEGO token.
 * <p>
 * Implementations of this interface are expected to be thread-safe.
 *
 * @since 4.1
 *
 * @deprecated (4.2)  subclass {@link KerberosScheme} and override
 *   {@link KerberosScheme#generateGSSToken(byte[], org.ietf.jgss.Oid, String)}
 */
@Deprecated
public interface SpnegoTokenGenerator {

    byte [] generateSpnegoDERObject(byte [] kerberosTicket) throws IOException;

}

==> httpclient-4.5.8-sources.jar: cz/msebera/android/httpclient/impl/auth/SpnegoTokenGenerator.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package cz.msebera.android.httpclient.impl.auth;

import java.io.IOException;

/**
 * Abstract SPNEGO token generator. Implementations should take an Kerberos ticket and transform
 * into a SPNEGO token.
 * <p>
 * Implementations of this interface are expected to be thread-safe.
 *
 * @since 4.1
 *
 * @deprecated (4.2)  subclass {@link KerberosScheme} and override
 *   {@link KerberosScheme#generateGSSToken(byte[], org.ietf.jgss.Oid, String, cz.msebera.android.httpclient.auth.Credentials)}
 */
@Deprecated
public interface SpnegoTokenGenerator {

    byte [] generateSpnegoDERObject(byte [] kerberosTicket) throws IOException;

}
